==> rendition-8.15.1.tgz: package/dist_esm5/components/DataTypes/boolean.js <==
import * as tslib_1 from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Select from '../Select';
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
};
export var decodeFilter = function (filter) {
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var field = keys[0];
    var operator = filter.title;
    var value;
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: (title || field) + " " + operators[operator].getLabel(schema) + " " + value,
        type: 'object',
    };
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    return base;
};
export var Edit = function (_a) {
    var value = _a.value, onUpdate = _a.onUpdate, props = tslib_1.__rest(_a, ["value", "onUpdate"]);
    return (React.createElement(Select, tslib_1.__assign({}, props, { value: value ? 'true' : 'false', onChange: function (e) {
            return onUpdate(e.currentTarget.value === 'true');
        } }),
        React.createElement("option", null, "true"),
        React.createElement("option", null, "false")));
};

==> rendition-9.4.0.tgz: package/dist_esm5/components/DataTypes/boolean.js <==
import * as tslib_1 from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Select from '../Select';
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
};
export var decodeFilter = function (filter) {
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var field = keys[0];
    var operator = filter.title;
    var value;
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: (title || field) + " " + operators[operator].getLabel(schema) + " " + value,
        type: 'object',
    };
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    return base;
};
export var Edit = function (_a) {
    var value = _a.value, onUpdate = _a.onUpdate, props = tslib_1.__rest(_a, ["value", "onUpdate"]);
    return (React.createElement(Select, tslib_1.__assign({}, props, { options: ['true', 'false'], value: value ? 'true' : 'false', onChange: function (_a) {
            var option = _a.option;
            return onUpdate(option === 'true');
        } })));
};
